@@ -33,6 +33,7 @@ from bfit.gui.tab_fetch_files import fetch_files
 from bfit.gui.tab_fit_files import fit_files
 from bfit.gui.calculator_nqr_B0 import calculator_nqr_B0
 from bfit.gui.calculator_nmr_B1 import calculator_nmr_B1
+from bfit.gui.calculator_nmr_atten import calculator_nmr_atten
 from bfit.gui.popup_drawstyle import popup_drawstyle
 from bfit.gui.popup_redraw_period import popup_redraw_period
 from bfit.gui.popup_terminal import popup_terminal
@@ -313,7 +314,8 @@ class bfit(object):
         """
         # logging
         self.logger = logging.getLogger(logger_name)
-        self.logger.info('Initializing ' + '-'*50)
+        self.logger.info('Initializing v%s' % __version__ + '-'*50)
+        self.logger.info('bdata: v%s' % bd.__version__)
         
         # plot tracker 
         self.plt = PltTracker()
@@ -425,8 +427,9 @@ class bfit(object):
         # File
         menu_file = Menu(menubar)
         menu_file.add_command(label='Search archive', command=self.search_archive)
-        menu_file.add_command(label='NMR B1 Calculator', command=calculator_nmr_B1)
         menu_file.add_command(label='NQR B0 Calculator', command=calculator_nqr_B0)
+        menu_file.add_command(label='NMR B1 Calculator', command=calculator_nmr_B1)
+        menu_file.add_command(label='NMR RF Attenuation', command=calculator_nmr_atten)
         menu_file.add_command(label='Run Commands', command=lambda:popup_terminal(wref.proxy(self)))
         menu_file.add_command(label='Export Data', command=self.do_export)
         menu_file.add_command(label='Export Fits', command=self.do_export_fit)
@@ -1254,7 +1257,9 @@ class bfit(object):
         # get new keys
         asym_out = {}
         for k in asym.keys():
+            
             if len(asym[k]) == 2:
+                
                 asym_out[title_dict[k]] = asym[k][0]
                 asym_out[title_dict[k]+"_err"] = asym[k][1]
             else:
